==> spammaster-8.x-2.6.tar.gz: spammaster/src/SpamMasterFormService.php <==
<?php

namespace Drupal\spammaster;

use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Session\AccountInterface;
use GuzzleHttp\Client;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Component\Serialization\Json;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class service.
 */
class SpamMasterFormService {
  use StringTranslationTrait;

  /**
   * The database connection object.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The session account interface.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The String Translation..
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $stringTranslation;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $form;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $formstate;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spamFormId;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasterip;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasteragent;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasteremail;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammastermessage;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterreferer;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterurl;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasteruserid;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterusername;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $connection, MessengerInterface $messenger, AccountInterface $account, RequestStack $requestStack, Client $httpClient, ConfigFactoryInterface $configFactory, StateInterface $state, TranslationInterface $stringTranslation) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->account = $account;
    $this->requestStack = $requestStack;
    $this->httpClient = $httpClient;
    $this->configFactory = $configFactory;
    $this->state = $state;
    $this->stringTranslation = $stringTranslation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('messenger'),
      $container->get('current_user'),
      $container->get('request_stack'),
      $container->get('http_client'),
      $container->get('config.factory'),
      $container->get('state'),
      $container->get('string_translation')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterFormCheck($form, $formstate, $spamFormId, $spammasterip, $spammasteragent, $spammasteremail, $spammastermessage, $spammasterreferer, $spammasterurl, $spammasteruserid, $spammasterusername) {

    $this->form = $form;
    $this->formstate = $formstate;
    $this->spamFormId = $spamFormId;
    $this->spammasterip = $spammasterip;
    $this->spammasteragent = $spammasteragent;
    $this->spammasteremail = $spammasteremail;
    $this->spammasterreferer = $spammasterreferer;
    $this->spammasterurl = $spammasterurl;
    $this->spammasteruserid = $spammasteruserid;
    $this->spammasterusername = $spammasterusername;
    $spammaster_date = date("Y-m-d H:i:s");
    $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
    $spammaster_license = $spammaster_settings->get('spammaster.license_key');
    $spammaster_status = $this->state->get('spammaster.license_status');
    $spammaster_total_block_count = $this->state->get('spammaster.total_block_count');
    $spammaster_settings_protection = $this->configFactory->getEditable('spammaster.settings_protection');
    $spammaster_block_message = $spammaster_settings_protection->get('spammaster.block_message');
    if ('VALID' === $spammaster_status || 'MALFUNCTION_1' === $spammaster_status || 'MALFUNCTION_2' === $spammaster_status) {
      $result_message_content_trim = $spamFormId . ' - ' . substr($spammastermessage, 0, 900);
      $result_message_content_clean = strip_tags($result_message_content_trim);
      // Email needs to be called first.
      $valid_email = filter_var($spammasteremail, FILTER_VALIDATE_EMAIL);
      if (empty($spammasteremail || is_array($spammasteremail) || $valid_email == FALSE)) {
        $spammasteremail = 'drup@' . rand(10000000, 99999999) . '.drup';
      }
      // Exempt whitelist.
      $spammaster_white_query = $this->connection->select('spammaster_white', 'u');
      $spammaster_white_query->fields('u', ['white']);
      $spammaster_white_query->where('(white = :ip OR white = :email)', [
        ':ip' => $spammasterip,
        ':email' => $spammasteremail,
      ]);
      $spammaster_white_result = $spammaster_white_query->execute()->fetchObject();
      // White positive, or administrator log insert.
      $user_roles = $this->account->getRoles();
      if (!empty($spammaster_white_result) || in_array('administrator', $user_roles)) {
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-firewall',
          'spamvalue' => 'Spam Master: firewall found in whitelist, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
        ])->execute();
      }
      else {
        // Buffer db check.
        $spammaster_spam_buffer_query = $this->connection->select('spammaster_threats', 'u');
        $spammaster_spam_buffer_query->fields('u', ['threat']);
        $spammaster_spam_buffer_query->where('(threat = :ip OR threat = :email)', [
          ':ip' => $spammasterip,
          ':email' => $spammasteremail,
        ]);
        $spammaster_spam_buffer_result = $spammaster_spam_buffer_query->execute()->fetchObject();
        // Buffer db positive, throw error, log insert.
        if (!empty($spammaster_spam_buffer_result)) {
          $formstate->setErrorByName('mail', $this->t('SPAM MASTER: @block_message', ['@block_message' => $spammaster_block_message]));
          // Check if ip is already listed in buffer.
          $spammaster_db_ip = $this->connection->select('spammaster_threats', 'u');
          $spammaster_db_ip->fields('u', ['threat']);
          $spammaster_db_ip->where('(threat = :ip)', [':ip' => $spammasterip]);
          $spammaster_db_ip_result = $spammaster_db_ip->execute()->fetchObject();
          if (empty($spammaster_db_ip_result)) {
            $this->connection->insert('spammaster_threats')->fields([
              'date' => $spammaster_date,
              'threat' => $spammasterip,
            ])->execute();
          }
          // Check if email is not spambot and already listed in buffer.
          if ($spammasteremail != 'Spam Bot') {
            $spammaster_db_email = $this->connection->select('spammaster_threats', 'u');
            $spammaster_db_email->fields('u', ['threat']);
            $spammaster_db_email->where('(threat = :email)', [':email' => $spammasteremail]);
            $spammaster_db_email_result = $spammaster_db_email->execute()->fetchObject();
            if (empty($spammaster_db_email_result)) {
              $this->connection->insert('spammaster_threats')->fields([
                'date' => $spammaster_date,
                'threat' => $spammasteremail,
              ])->execute();
            }
          }
          $spammaster_total_block_count_1 = ++$spammaster_total_block_count;
          $this->state->set('spammaster.total_block_count', $spammaster_total_block_count_1);

          $this->connection->insert('spammaster_keys')->fields([
            'date' => $spammaster_date,
            'spamkey' => 'spammaster-firewall',
            'spamvalue' => 'Spam Master: firewall buffer block, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
          ])->execute();
          throw new AccessDeniedHttpException();
        }
        // Web api check.
        else {
          // Route form request to endpoint.
          $spammaster_router_needle = [
            'user',
            'login',
            'register',
            'contact',
            'webform',
            'comment',
          ];
          foreach ($spammaster_router_needle as $router) {
            if (stristr($spamFormId, $router) !== FALSE) {
              switch ($router) {
                case "login":
                  $blog_threat_type = 'Login';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "register":
                  $blog_threat_type = 'Registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "user":
                  $blog_threat_type = 'Registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "contact":
                  $blog_threat_type = 'Contact';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                case "webform":
                  $blog_threat_type = 'Contact';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                case "comment":
                  $blog_threat_type = 'Comment';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                default:
                  $blog_threat_type = 'Registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;
              }
              break;
            }
          }
          // Create data to be posted.
          $blog_web_address = $this->requestStack->getCurrentRequest()->getHost();
          $address_unclean = $blog_web_address;
          $address = preg_replace('#^https?://#', '', $address_unclean);
          @$blog_server_ip = $_SERVER['SERVER_ADDR'];
          // If empty ip.
          if (empty($blog_server_ip) || $blog_server_ip == '0') {
            @$blog_server_ip = 'I ' . gethostbyname($_SERVER['SERVER_NAME']);
          }
          // Call drupal hhtpclient.
          $client = $this->httpClient;
          // Post data.
          $request = $client->post(base64_decode($spam_master_leaning_url), [
            'form_params' => [
              'blog_license_key'    => $spammaster_license,
              'blog_threat_ip'      => $spammasterip,
              'blog_threat_user'    => $spammasteruserid,
              'blog_threat_type'    => $blog_threat_type,
              'blog_threat_email'   => $spammasteremail,
              'blog_threat_content' => $result_message_content_trim,
              'blog_threat_agent'   => $spammasteragent,
              'blog_threat_refe'    => $spammasterreferer,
              'blog_threat_dest'    => $spammasterurl,
              'blog_web_adress'     => $address,
              'blog_server_ip'      => $blog_server_ip,
            ],
          ]);
          // Decode json data.
          $response = Json::decode($request->getBody());
          if (empty($response['threat'])) {
            // Log clean rbl check.
            $this->connection->insert('spammaster_keys')->fields([
              'date' => $spammaster_date,
              'spamkey' => 'spammaster-firewall',
              'spamvalue' => 'Spam Master: firewall approved, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
            ])->execute();
          }
          else {
            // Insert ip into buffer db.
            $this->connection->insert('spammaster_threats')->fields([
              'date' => $spammaster_date,
              'threat' => $spammasterip,
            ])->execute();
            // Check if email is not spambot and already listed in buffer.
            if ($spammasteremail != 'Spam Bot') {
              $spammaster_db_email = $this->connection->select('spammaster_threats', 'u');
              $spammaster_db_email->fields('u', ['threat']);
              $spammaster_db_email->where('(threat = :email)', [':email' => $spammasteremail]);
              $spammaster_db_email_result = $spammaster_db_email->execute()->fetchObject();
              if (empty($spammaster_db_email_result)) {
                $this->connection->insert('spammaster_threats')->fields([
                  'date' => $spammaster_date,
                  'threat' => $spammasteremail,
                ])->execute();
              }
            }
            // Web positive, throw error.
            $formstate->setErrorByName('mail', $this->t('SPAM MASTER: @block_message', ['@block_message' => $spammaster_block_message]));
            $spammaster_total_block_count_1 = ++$spammaster_total_block_count;
            $this->state->set('spammaster.total_block_count', $spammaster_total_block_count_1);
            $this->connection->insert('spammaster_keys')->fields([
              'date' => $spammaster_date,
              'spamkey' => 'spammaster-firewall',
              'spamvalue' => 'Spam Master: firewall rbl block, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
            ])->execute();
            throw new AccessDeniedHttpException();
          }
        }
      }
    }
  }

}

==> spammaster-8.x-2.7.tar.gz: spammaster/src/SpamMasterFormService.php <==
<?php

namespace Drupal\spammaster;

use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Session\AccountInterface;
use GuzzleHttp\Client;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Component\Serialization\Json;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class service.
 */
class SpamMasterFormService {
  use StringTranslationTrait;

  /**
   * The database connection object.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The session account interface.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The String Translation..
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $stringTranslation;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $form;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $formstate;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spamFormId;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasterip;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasteragent;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammasteremail;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $spammastermessage;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterreferer;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterurl;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasteruserid;

  /**
   * The SpamMasterRegistrationService service.
   *
   * @var \Drupal\spammmaster\SpamMasterRegistrationService
   */
  protected $spammasterusername;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $connection, MessengerInterface $messenger, AccountInterface $account, RequestStack $requestStack, Client $httpClient, ConfigFactoryInterface $configFactory, StateInterface $state, TranslationInterface $stringTranslation) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->account = $account;
    $this->requestStack = $requestStack;
    $this->httpClient = $httpClient;
    $this->configFactory = $configFactory;
    $this->state = $state;
    $this->stringTranslation = $stringTranslation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('messenger'),
      $container->get('current_user'),
      $container->get('request_stack'),
      $container->get('http_client'),
      $container->get('config.factory'),
      $container->get('state'),
      $container->get('string_translation')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterFormCheck($form, $formstate, $spamFormId, $spammasterip, $spammasteragent, $spammasteremail, $spammastermessage, $spammasterreferer, $spammasterurl, $spammasteruserid, $spammasterusername) {

    $this->form = $form;
    $this->formstate = $formstate;
    $this->spamFormId = $spamFormId;
    $this->spammasterip = $spammasterip;
    $this->spammasteragent = $spammasteragent;
    $this->spammasteremail = $spammasteremail;
    $this->spammastermessage = $spammastermessage;
    $this->spammasterreferer = $spammasterreferer;
    $this->spammasterurl = $spammasterurl;
    $this->spammasteruserid = $spammasteruserid;
    $this->spammasterusername = $spammasterusername;
    $spammaster_date = date("Y-m-d H:i:s");
    $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
    $spammaster_license = $spammaster_settings->get('spammaster.license_key');
    $spammaster_status = $this->state->get('spammaster.license_status');
    $spammaster_total_block_count = $this->state->get('spammaster.total_block_count');
    $spammaster_settings_protection = $this->configFactory->getEditable('spammaster.settings_protection');
    $spammaster_block_message = $spammaster_settings_protection->get('spammaster.block_message');
    if ('VALID' === $spammaster_status || 'MALFUNCTION_1' === $spammaster_status || 'MALFUNCTION_2' === $spammaster_status) {
      $result_message_content_trim = substr($spamFormId, 0, 85) . ' - ' . substr($spammastermessage, 0, 900);
      $result_message_content_clean = strip_tags($result_message_content_trim);
      // Email needs to be called first.
      $valid_email = filter_var($spammasteremail, FILTER_VALIDATE_EMAIL);
      if (empty($spammasteremail || is_array($spammasteremail) || $valid_email == FALSE)) {
        $spammasteremail = 'drup@' . rand(10000000, 99999999) . '.drup';
      }
      // Exempt whitelist.
      $spammaster_white_query = $this->connection->select('spammaster_white', 'u');
      $spammaster_white_query->fields('u', ['white']);
      $spammaster_white_query->where('(white = :ip OR white = :email)', [
        ':ip' => $spammasterip,
        ':email' => $spammasteremail,
      ]);
      $spammaster_white_result = $spammaster_white_query->execute()->fetchObject();
      // White positive, or administrator log insert.
      $user_roles = $this->account->getRoles();
      if (!empty($spammaster_white_result) || in_array('administrator', $user_roles)) {
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-firewall',
          'spamvalue' => 'Spam Master: form submission found in whitelist, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
        ])->execute();
      }
      else {
        // Buffer db check.
        $spammaster_spam_buffer_query = $this->connection->select('spammaster_threats', 'u');
        $spammaster_spam_buffer_query->fields('u', ['threat']);
        $spammaster_spam_buffer_query->where('(threat = :ip OR threat = :email)', [
          ':ip' => $spammasterip,
          ':email' => $spammasteremail,
        ]);
        $spammaster_spam_buffer_result = $spammaster_spam_buffer_query->execute()->fetchObject();
        // Buffer db positive, throw error, log insert.
        if (!empty($spammaster_spam_buffer_result)) {
          $formstate->setErrorByName('mail', $this->t('SPAM MASTER: @block_message', ['@block_message' => $spammaster_block_message]));
          // Check if ip is already listed in buffer.
          $spammaster_db_ip = $this->connection->select('spammaster_threats', 'u');
          $spammaster_db_ip->fields('u', ['threat']);
          $spammaster_db_ip->where('(threat = :ip)', [':ip' => $spammasterip]);
          $spammaster_db_ip_result = $spammaster_db_ip->execute()->fetchObject();
          if (empty($spammaster_db_ip_result)) {
            $this->connection->insert('spammaster_threats')->fields([
              'date' => $spammaster_date,
              'threat' => $spammasterip,
            ])->execute();
          }
          // Check if email is not spambot and already listed in buffer.
          if ($spammasteremail != 'Spam Bot') {
            $spammaster_db_email = $this->connection->select('spammaster_threats', 'u');
            $spammaster_db_email->fields('u', ['threat']);
            $spammaster_db_email->where('(threat = :email)', [':email' => $spammasteremail]);
            $spammaster_db_email_result = $spammaster_db_email->execute()->fetchObject();
            if (empty($spammaster_db_email_result)) {
              $this->connection->insert('spammaster_threats')->fields([
                'date' => $spammaster_date,
                'threat' => $spammasteremail,
              ])->execute();
            }
          }
          $spammaster_total_block_count_1 = ++$spammaster_total_block_count;
          $this->state->set('spammaster.total_block_count', $spammaster_total_block_count_1);

          $this->connection->insert('spammaster_keys')->fields([
            'date' => $spammaster_date,
            'spamkey' => 'spammaster-firewall',
            'spamvalue' => 'Spam Master: form submission BUFFER BLOCK, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
          ])->execute();
          throw new AccessDeniedHttpException();
        }
        // Web api check.
        else {
          // Route form request to endpoint.
          $spammaster_router_needle = [
            'user',
            'login',
            'register',
            'contact',
            'webform',
            'comment',
          ];
          foreach ($spammaster_router_needle as $router) {
            if (stristr($spamFormId, $router) !== FALSE) {
              switch ($router) {
                case "login":
                  $blog_threat_type = 'login';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "register":
                  $blog_threat_type = 'registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "user":
                  $blog_threat_type = 'registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;

                case "contact":
                  $blog_threat_type = 'contact-form';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                case "webform":
                  $blog_threat_type = 'contact-form';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                case "comment":
                  $blog_threat_type = 'comment';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2NvbV8yLnBocA==';
                  break;

                default:
                  $blog_threat_type = 'registration';
                  $spam_master_leaning_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX3JlZ18yLnBocA==';
                  break;
              }
              break;
            }
          }
          // Create data to be posted.
          $blog_web_address = $this->requestStack->getCurrentRequest()->getHost();
          $address_unclean = $blog_web_address;
          $address = preg_replace('#^https?://#', '', $address_unclean);
          @$blog_server_ip = $_SERVER['SERVER_ADDR'];
          // If empty ip.
          if (empty($blog_server_ip) || $blog_server_ip == '0') {
            @$blog_server_ip = 'I ' . gethostbyname($_SERVER['SERVER_NAME']);
          }
          // Call drupal hhtpclient.
          $client = $this->httpClient;
          // Post data.
          $request = $client->post(base64_decode($spam_master_leaning_url), [
            'form_params' => [
              'blog_license_key'    => $spammaster_license,
              'blog_threat_ip'      => $spammasterip,
              'blog_threat_user'    => $spammasteruserid,
              'blog_threat_type'    => $blog_threat_type,
              'blog_threat_email'   => $spammasteremail,
              'blog_threat_content' => $result_message_content_trim,
              'blog_threat_agent'   => $spammasteragent,
              'blog_threat_refe'    => $spammasterreferer,
              'blog_threat_dest'    => $spammasterurl,
              'blog_web_adress'     => $address,
              'blog_server_ip'      => $blog_server_ip,
            ],
          ]);
          // Decode json data.
          $response = Json::decode($request->getBody());
          if (empty($response['threat'])) {
            // Log clean rbl check.
            $this->connection->insert('spammaster_keys')->fields([
              'date' => $spammaster_date,
              'spamkey' => 'spammaster-firewall',
              'spamvalue' => 'Spam Master: form submission approved, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
            ])->execute();
          }
          else {
            // Insert ip into buffer db.
            $this->connection->insert('spammaster_threats')->fields([
              'date' => $spammaster_date,
              'threat' => $spammasterip,
            ])->execute();
            // Check if email is not spambot and already listed in buffer.
            if ($spammasteremail != 'Spam Bot') {
              $spammaster_db_email = $this->connection->select('spammaster_threats', 'u');
              $spammaster_db_email->fields('u', ['threat']);
              $spammaster_db_email->where('(threat = :email)', [':email' => $spammasteremail]);
              $spammaster_db_email_result = $spammaster_db_email->execute()->fetchObject();
              if (empty($spammaster_db_email_result)) {
                $this->connection->insert('spammaster_threats')->fields([
                  'date' => $spammaster_date,
                  'threat' => $spammasteremail,
                ])->execute();
              }
            }
            // Web positive, throw error.
            $formstate->setErrorByName('mail', $this->t('SPAM MASTER: @block_message', ['@block_message' => $spammaster_block_message]));
            $spammaster_total_block_count_1 = ++$spammaster_total_block_count;
            $this->state->set('spammaster.total_block_count', $spammaster_total_block_count_1);
            $this->connection->insert('spammaster_keys')->fields([
              'date' => $spammaster_date,
              'spamkey' => 'spammaster-firewall',
              'spamvalue' => 'Spam Master: form submission RBL BLOCK, Ip: ' . $spammasterip . ', Email: ' . $spammasteremail . ', Message: ' . $result_message_content_clean . ', Agent: ' . $spammasteragent . ', User ID: ' . $spammasteruserid . ', Username: ' . $spammasterusername,
            ])->execute();
            throw new AccessDeniedHttpException();
          }
        }
      }
    }
  }

}
